#!/usr/bin/env python

from I3Tray import *
from I3Units import *
from math import *
from os.path import expandvars


import os

eve_num = 100
physfile  = "tmp.i3"
stream_num = 10

if len(sys.argv) > 1:
	physfile = sys.argv[1]
if len(sys.argv) > 2:
	stream_num = int(sys.argv[2])

load("libc2j-icetray")
load("libicetray")
load("libdataclasses")
load('libdataio')
load("libphys-services")
load("libsim-services")
load("libjuliet-interface")
load("libromeo")
load("libPSInterface")
load("libDOMcalibrator")
load("libDOMsimulator")
load("libPSInterfaceFactory")
load("libbrutus")


tray = I3Tray()

photonics = expandvars("$I3_BUILD/")

tray.AddService("I3JavaVMFactory", "java_vm")(
        ("Options",[expandvars("-Djava.class.path=$I3_WORK/../src/juliet/java_lib/classes"), "-Xms256m", "-Xmx512m"]))

tray.AddService("I3MCTimeGeneratorServiceFactory","time-gen")(
	("Year",2007),
        ("DAQTime",173357040000000000)
	)

gcd_file = expandvars("$I3_TOOLS/test-data/sim/GCD.i3.gz")

tray.AddService("I3ReaderServiceFactory","reader")(
	("Filename",gcd_file),
	("OmitEvent",True)
	)

stringsToUse = "21,29,30,38,39,40,49,50,59,58,67,66,74,73,65,72,78,48,57,47,46,56"
stationsToUse = "21,29,30,38,39,40,47,48,49,50,57,58,59,66,67,74,46,56,65,73,72,78,77,71,64,55"

tray.AddService("I3GeometrySelectorServiceFactory","geo-selector")(
	("StringsToUse",stringsToUse),
	("StationsToUse",stationsToUse),
	("GeoSelectorName","IC22-IT26-Geo")
	)

tray.AddService("I3PSInterfaceFactory","PSInterface")(
	("Interface","Photonics"),
	("TablesDirectory",photonics),
	("DriverFilePath",photonics),
	("PhotonicsLevel1DriverFile","level1_table.list"),
	("PhotonicsLevel2DriverFile","level2_table.list"),
	("PhotonicsTableSelection",1) # cascade only
	)

tray.AddService("I3SPRNGRandomServiceFactory","random")(
        ("Seed",1),
        ("NStreams",10000),
        ("StreamNum",stream_num))


tray.AddModule("I3Muxer","muxer")(
	("GeometryService","IC22-IT26-Geo")
	)

tray.AddModule("I3JulietPrimaryParticleSource","fillprimary")(
     ("PrimaryFlavor",1),  #[e, mu, tau]=[0, 1, 2]
     ("PrimaryDoublet",1), #[neutrino, charged]=[0, 1]
     ("EnergyMin", 1.E5*I3Units.GeV),  #[GeV]
     ("EnergyMax", 1.E11*I3Units.GeV),
     ("DifferentialPowerLawIndex", 1.),
     ("InjectPositionX",310.*I3Units.m),
     ("InjectPositionY",189.*I3Units.m),
     ("InjectPositionZ",0.*I3Units.m),
     ("InjectRadius",880.*I3Units.m),
     ("NadirMin",0.*I3Units.deg),
     ("NadirMax",180.*I3Units.deg),
     ("AzimuthMin",0.*I3Units.deg),
     ("AzimuthMax",360.*I3Units.deg),
     ("NeutrinoInteractionWeight", 1)
     )

tray.AddModule("I3Juliet","propagate")(
     ("MaterialID",0),  #[ice, rock]=[0, 1]
     ("Flavor",1),      #[e, mu, tau]=[0, 1, 2]
                        #This should be same as the PrimaryFlavor
     ("DoChargedCurrent",0),
     ("DoNeutralCurrent",0),
     ("DoMuBremss",1),
     ("DoTauBremss",0),
     ("DoMuKnockOn",0),
     ("DoTauKnockOn",0),
     ("DoMu2ePairCreation",1),
     ("DoTau2ePairCreation",0),
     ("DoMu2muPairCreation",0),
     ("DoTau2muPairCreation",0),
     ("DoMu2tauPairCreation",0),
     ("DoTau2tauPairCreation",0),
     ("DoMuPhotoNuclear",1),
     ("DoTauPhotoNuclear",0),
     ("DoMuDecay",1),
     ("DoTauDecay",0),
     ("StartLocationID",2)  # 1: from the Earth surface
                            # 2: 880m away from the IceCube center
     )

tray.AddModule("I3HitConstructorModuleEHE","hit-constructor-ehe")(
	("MaxMCHits", 1000000)
	)

tray.AddModule("I3RomeoInterfaceModule","romeo")(
	("SkipPhotoCathodeSimulator", False),
        ("StorePMTPulses", False),                     # skip to store ceCubePMTPulse
        ("RomeoOutputTimeResolution", 10.*I3Units.ns), # must same as MCHitBinSize of I3MCHitCompressor
        ("RomeoVerboseLevel", 0)                       # verbose level, 0=silence to 5=trace
     )

tray.AddModule("I3DOMsimulator","domsimulator")(
	("SimulatePedestalDroop",True)
	)

tray.AddModule("I3DOMcalibrator","domcalibrator")(
	("InputRawDataName","InIceRawData"),
	("CalibrationMode",1),
	("CorrectPedestalDroopDualTau", False)
	)

tray.AddModule("I3RawDataEraser","eraser")(
	("DataReadoutName","InIceRawData"),
	("eraseFADC", False) # false: keep calibratedFADCs, but delete rawFADCs
)

tray.AddModule("I3Writer","writer")(
        ("filename", physfile),
	("skipkeys", ["FrameIndex"]),
	("streams",["Physics"])
)

if stream_num == 0:(
	tray.AddModule("I3Writer","writer2")(
	("filename", "GCD.i3.gz"),
	("skipkeys", ["FrameIndex"]),
	("streams",["Geometry","Calibration","DetectorStatus"])
	)
	)

tray.AddModule("Dump","dump")
tray.AddModule("TrashCan", "the can")

tray.Execute(eve_num)
tray.Finish()
